@@ -48,11 +48,11 @@ class FunctionPlacer(object):
         self.fig = fig
         self.ncomp = ncomp
         self.base = base
-        self.fn = lambda x,**kwargs : fn_single(x,**kwargs)+self.base
+        self.fn = lambda x, **kwargs : fn_single(x, **kwargs)+self.base
         self.fname = fnname
         self.endfn = endfn
         x = data.asym(asym_mode)[0]
-        self.x = np.linspace(min(x),max(x),self.npts)
+        self.x = np.linspace(min(x), max(x), self.npts)
         self.spin = spin
         
         # get axes for drawing
@@ -69,102 +69,102 @@ class FunctionPlacer(object):
         self.p0 = [{k:float(p[k].get()) for k in p.keys() if 'base' not in k} for p in p0]
     
         # baseline 
-        if self.fname in ('Lorentzian','Gaussian','BiLorentzian','QuadLorentz'):
+        if self.fname in ('Lorentzian', 'Gaussian', 'BiLorentzian', 'QuadLorentz'):
             self.base = float(p0[0]['base'].get())
             y = np.ones(len(self.x))*self.base
-            self.baseline = self.ax.plot(self.x,y,zorder=20,ls='--')[0]
+            self.baseline = self.ax.plot(self.x, y, zorder=20, ls='--')[0]
         else:
             self.base = 0
             self.baseline = dummybaseline()
     
         # draw each line with initial parameters
-        self.lines = [self.ax.plot(self.x,
-                                   fn_single(self.x,**self.p0[i])+self.base,
-                                   zorder=20,ls='--')[0] for i in range(ncomp)]
+        self.lines = [self.ax.plot(self.x, 
+                                   fn_single(self.x, **self.p0[i])+self.base, 
+                                   zorder=20, ls='--')[0] for i in range(ncomp)]
         
         # make and draw function for the sum 
-        self.sumfn = lambda x: np.sum([fn_single(x,**p) for p in self.p0],axis=0)+self.base
-        self.sumline = self.ax.plot(self.x,self.sumfn(self.x),zorder=21,ls='-')[0]
+        self.sumfn = lambda x: np.sum([fn_single(x, **p) for p in self.p0], axis=0)+self.base
+        self.sumline = self.ax.plot(self.x, self.sumfn(self.x), zorder=21, ls='-')[0]
         
         # reset ylims
         self.ax.set_ylim(ylims)
         
         # make title 
-        self.ax.set_title('Press enter to save parameters',fontsize='small')
+        self.ax.set_title('Press enter to save parameters', fontsize='small')
         self.fig.tight_layout()
         
         # connect enter key
-        self.fig.canvas.mpl_connect('key_release_event',self.do_end)
+        self.fig.canvas.mpl_connect('key_release_event', self.do_end)
         
         # resonance measurements ----------------------------------------------
-        if self.fname in ('Lorentzian','Gaussian'):
+        if self.fname in ('Lorentzian', 'Gaussian'):
             
             # if points are not saved they are garbage collected
-            self.list_points = {'peak':[],'fwhm':[]}
+            self.list_points = {'peak':[], 'fwhm':[]}
             
             # make points
-            for i,(p,line) in enumerate(zip(self.p0,self.lines)):
-                peakpt,widthpt = self.run_1f_single(p,line,'C%d'%(i+1))
+            for i, (p, line) in enumerate(zip(self.p0, self.lines)):
+                peakpt, widthpt = self.run_1f_single(p, line, 'C%d'%(i+1))
                 self.list_points['peak'].append(peakpt)
                 self.list_points['fwhm'].append(widthpt)
         
-            self.list_points['base'] = self.run_1f_base(self.list_points['fwhm'],'C0')
+            self.list_points['base'] = self.run_1f_base(self.list_points['fwhm'], 'C0')
         
         elif self.fname == 'BiLorentzian':
             
             # if points are not saved they are garbage collected
-            self.list_points = {'peak':[],'fwhm':[]}
+            self.list_points = {'peak':[], 'fwhm':[]}
             
             # make points
-            for i,(p,line) in enumerate(zip(self.p0,self.lines)):
-                peakpt,widthpt = self.run_1f_bi_single(p,line,'C%d'%(i+1))
+            for i, (p, line) in enumerate(zip(self.p0, self.lines)):
+                peakpt, widthpt = self.run_1f_bi_single(p, line, 'C%d'%(i+1))
                 self.list_points['peak'].append(peakpt)
                 self.list_points['fwhm'].append(widthpt)
         
-            self.list_points['base'] = self.run_1f_base(self.list_points['fwhm'],'C0')
+            self.list_points['base'] = self.run_1f_base(self.list_points['fwhm'], 'C0')
         
         elif self.fname == 'QuadLorentz':
             
             # if points are not saved they are garbage collected
-            self.list_points = {'peak0':[],'peak1':[],'peak2':[],'peak3':[],'fwhm':[],}
+            self.list_points = {'peak0':[], 'peak1':[], 'peak2':[], 'peak3':[], 'fwhm':[], }
             
             # make points
-            for i,(p,line) in enumerate(zip(self.p0,self.lines)):
-                ppt0,ppt1,ppt2,ppt3,widthpt = self.run_1f_quad_single(p,line,'C%d'%(i+1))
+            for i, (p, line) in enumerate(zip(self.p0, self.lines)):
+                ppt0, ppt1, ppt2, ppt3, widthpt = self.run_1f_quad_single(p, line, 'C%d'%(i+1))
                 self.list_points['peak0'].append(ppt0)
                 self.list_points['peak1'].append(ppt1)
                 self.list_points['peak2'].append(ppt2)
                 self.list_points['peak3'].append(ppt3)
                 self.list_points['fwhm'].append(widthpt)
-            self.list_points['base'] = self.run_1f_quad_base(self.p0[0],self.list_points['fwhm'],'C0')
+            self.list_points['base'] = self.run_1f_quad_base(self.p0[0], self.list_points['fwhm'], 'C0')
             
         # SLR measurements ----------------------------------------------------
-        elif self.fname in ('Exp','Str Exp'):
+        elif self.fname in ('Exp', 'Str Exp'):
             
             # if points are not saved they are garbage collected
-            self.list_points = {'amp':[],'lam':[]}
+            self.list_points = {'amp':[], 'lam':[]}
             
             if self.fname == 'Str Exp':
                 self.list_points['beta'] = []
             
             # make points
-            for i,(p,line) in enumerate(zip(self.p0,self.lines)):
-                self.list_points['amp'].append(self.run_20_initial(p,line,'C%d'%i))
-                self.list_points['lam'].append(self.run_20_lambda(p,line,'C%d'%i))
+            for i, (p, line) in enumerate(zip(self.p0, self.lines)):
+                self.list_points['amp'].append(self.run_20_initial(p, line, 'C%d'%i))
+                self.list_points['lam'].append(self.run_20_lambda(p, line, 'C%d'%i))
                 
                 if self.fname == 'Str Exp':
-                    self.list_points['beta'].append(self.run_20_beta(p,line,'C%d'%i))
+                    self.list_points['beta'].append(self.run_20_beta(p, line, 'C%d'%i))
             
             # connect point shifter
-            self.fig.canvas.mpl_connect('button_release_event',self.shift_20_pts_resize)
+            self.fig.canvas.mpl_connect('button_release_event', self.shift_20_pts_resize)
             
     # ======================================================================= #
-    def run_1f_base(self,widths,color):
+    def run_1f_base(self, widths, color):
         """
             widths: list of points for widths, need to update y values
         """
         
-        def update_base(x,y):
+        def update_base(x, y):
             
             # base point
             oldbase = self.base
@@ -173,11 +173,11 @@ class FunctionPlacer(object):
                 self.p0[i]['amp'] -= oldbase-y
             
             # update width points
-            for p0,wpoint,line in zip(self.p0,widths,self.lines): 
-                wpoint.point.set_ydata(self.fn(p0['peak']+p0['fwhm'],**p0))
+            for p0, wpoint, line in zip(self.p0, widths, self.lines): 
+                wpoint.point.set_ydata(self.fn(p0['peak']+p0['fwhm']/2, **p0))
                 
                 # update other lines
-                line.set_ydata(self.fn(self.x,**p0))
+                line.set_ydata(self.fn(self.x, **p0))
             
             # update sumline
             self.sumline.set_ydata(self.sumfn(self.x))
@@ -188,112 +188,112 @@ class FunctionPlacer(object):
              
         # return so matplotlib doesn't garbage collect
         xpt = self.ax.get_xticks()[-1]
-        return DraggablePoint(self,update_base,xpt,
-                                 self.base,
-                                 color=color,setx=False)
+        return DraggablePoint(self, update_base, xpt, 
+                                 self.base, 
+                                 color=color, setx=False)
     
     # ======================================================================= #
-    def run_1f_single(self,p0,line,color):
+    def run_1f_single(self, p0, line, color):
         
         # make point for width
-        def update_width(x,y):
+        def update_width(x, y):
             
             # width point
-            p0['fwhm'] = abs(p0['peak']-x)
+            p0['fwhm'] = abs(p0['peak']-x)*2
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
              
-        x = p0['peak']+p0['fwhm']
-        widthpt = DraggablePoint(self,update_width,x,self.fn(x,**p0),
-                                 color=color,sety=False)
+        x = p0['peak']+p0['fwhm']/2
+        widthpt = DraggablePoint(self, update_width, x, self.fn(x, **p0), 
+                                 color=color, sety=False)
         
         # make point for peak
-        def update_peak(x,y):
+        def update_peak(x, y):
         
             # peak point
             p0['amp'] = self.base-y
             p0['peak'] = x
         
             # width point
-            x2 = x+p0['fwhm']
+            x2 = x+p0['fwhm']/2
             widthpt.point.set_xdata(x2)
-            widthpt.point.set_ydata(self.fn(x2,**p0))
+            widthpt.point.set_ydata(self.fn(x2, **p0))
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
         
-        peakpt = DraggablePoint(self,update_peak,p0['peak'],
-                                self.base-p0['amp'],color=color)
+        peakpt = DraggablePoint(self, update_peak, p0['peak'], 
+                                self.base-p0['amp'], color=color)
         
-        return (peakpt,widthpt)
+        return (peakpt, widthpt)
     
     # ======================================================================= #
-    def run_1f_bi_single(self,p0,line,color):
+    def run_1f_bi_single(self, p0, line, color):
         
         # make point for width
-        def update_width(x,y):
+        def update_width(x, y):
             
             # width point
-            p0['fwhm'] = abs(p0['peak']-x)
+            p0['fwhm'] = abs(p0['peak']-x)*2
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
              
-        x = p0['peak']+p0['fwhm']
-        widthpt = DraggablePoint(self,update_width,x,self.fn(x,**p0),
-                                 color=color,sety=False)
+        x = p0['peak']+p0['fwhm']/2
+        widthpt = DraggablePoint(self, update_width, x, self.fn(x, **p0), 
+                                 color=color, sety=False)
         
         # make point for peak
-        def update_peak(x,y):
+        def update_peak(x, y):
         
             # peak point
             p0['amp'] = self.base-y
             p0['peak'] = x
         
             # width point
-            x2 = x+p0['fwhm']
+            x2 = x+p0['fwhm']/2
             widthpt.point.set_xdata(x2)
-            widthpt.point.set_ydata(self.fn(x2,**p0))
+            widthpt.point.set_ydata(self.fn(x2, **p0))
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
         
-        peakpt = DraggablePoint(self,update_peak,p0['peak'],
-                                self.base-p0['amp'],color=color)
+        peakpt = DraggablePoint(self, update_peak, p0['peak'], 
+                                self.base-p0['amp'], color=color)
         
-        return (peakpt,widthpt)
+        return (peakpt, widthpt)
      
     # ======================================================================= #
-    def run_1f_quad_base(self,p0,widths,color):
+    def run_1f_quad_base(self, p0, widths, color):
         """
             widths: list of points for widths, need to update y values
         """
-        
         peak0 = qp_nu(p0['nu_0'], p0['nu_q'], p0['eta'], p0['theta'], p0['phi'], \
                           self.spin, -1)
         
-        def update_base(x,y):
+        def update_base(x, y):
             
             # base point
             oldbase = self.base
             self.base = y
+        
             for i in range(len(self.p0)):
                 self.p0[i]['amp0'] -= oldbase-y
                 self.p0[i]['amp1'] -= oldbase-y
@@ -301,11 +301,11 @@ class FunctionPlacer(object):
                 self.p0[i]['amp3'] -= oldbase-y
             
             # update width points
-            for p0,wpoint,line in zip(self.p0,widths,self.lines): 
-                wpoint.point.set_ydata(self.fn(peak0+p0['fwhm'],**p0))
+            for p0, wpoint, line in zip(self.p0, widths, self.lines): 
+                wpoint.point.set_ydata(self.fn(peak0+p0['fwhm']/2, **p0))
                 
                 # update other lines
-                line.set_ydata(self.fn(self.x,**p0))
+                line.set_ydata(self.fn(self.x, **p0))
             
             # update sumline
             self.sumline.set_ydata(self.sumfn(self.x))
@@ -317,12 +317,12 @@ class FunctionPlacer(object):
         # return so matplotlib doesn't garbage collect
         xpt = self.ax.get_xticks()[-1]
         
-        return DraggablePoint(self,update_base,xpt,
-                                 self.base,
-                                 color=color,setx=False)
+        return DraggablePoint(self, update_base, xpt, 
+                                 self.base, 
+                                 color=color, setx=False)
         
     # ======================================================================= #
-    def run_1f_quad_single(self,p0,line,color):
+    def run_1f_quad_single(self, p0, line, color):
         """
             p0 keys: 'amp0', 'amp1', 'amp2', 'amp3', 'eta', 'phi', 'theta', 'fwhm', 'nu_0', 'nu_q'
         """
@@ -335,9 +335,9 @@ class FunctionPlacer(object):
                                p0['phi'], s, i-s+1)
         
         # set width
-        x = peak(0)+p0['fwhm']                  
-        widthpt = DraggablePoint(self,None,x,self.fn(x,**p0),
-                                 color=color,sety=False)
+        x = peak(0)+p0['fwhm']/2
+        widthpt = DraggablePoint(self, None, x, self.fn(x, **p0), 
+                                 color=color, sety=False)
         
         # set peak and amplitudes
         peakpts = []
@@ -346,71 +346,70 @@ class FunctionPlacer(object):
             
             y = self.base - \
                 p0['amp%d'%n] + \
-                sum([lorentzian(peak(n),
-                                peak(i%(2*s)),
-                                p0['fwhm'],
-                                p0['amp%d'%(i%(2*s))]) for i in range(n+1,2*s+n)])                    
+                sum([lorentzian(peak(n), 
+                                peak(i%(2*s)), 
+                                p0['fwhm'], 
+                                p0['amp%d'%(i%(2*s))]) for i in range(n+1, 2*s+n)])                    
             
-            if n in (0,2*s-1):
+            if n in (0, 2*s-1):
                 peakpts.append(DraggablePoint(self, None, x, y, color=color, marker='s'))
             else:
-                peakpts.append(DraggablePoint(self, None, x, y, color=color, marker='^',setx=False))
+                peakpts.append(DraggablePoint(self, None, x, y, color=color, marker='^', setx=False))
             
         # make point for width
-        def update_width(x,y):
+        def update_width(x, y):
                         
             # width point
-            p0['fwhm'] = abs(peak(0)-x)
+            p0['fwhm'] = abs(peak(0)-x)*2
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update peak heights
             for i in range(2*s):
-                peakpts[i].point.set_ydata(self.fn(peak(i),**p0))
+                peakpts[i].point.set_ydata(self.fn(peak(i), **p0))
             
             # update width y 
-            widthpt.point.set_ydata(self.fn(x,**p0))
+            widthpt.point.set_ydata(self.fn(x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
 
         # make point for peak, updating nu_0
-        def update_peak_center(x,y,n):
+        def update_peak_center(x, y, n):
             
             # peak point
             p0['amp%d'%n] = self.base - y + \
-                        sum([lorentzian(peak(n),
-                                        peak(i%(2*s)),
-                                        p0['fwhm'],
-                                        p0['amp%d'%(i%(2*s))]) for i in range(n+1,2*s+n)])
+                        sum([lorentzian(peak(n), 
+                                        peak(i%(2*s)), 
+                                        p0['fwhm'], 
+                                        p0['amp%d'%(i%(2*s))]) for i in range(n+1, 2*s+n)])
             
             # width point        
-            x2 = peak(0)+p0['fwhm']
-            # ~ widthpt.point.set_xdata(x2)
-            widthpt.point.set_ydata(self.fn(x2,**p0))
+            x2 = peak(0)+p0['fwhm']/2
+            widthpt.point.set_ydata(self.fn(x2, **p0))
         
             # update the other peak points
-            for i in range(n+1,2*s+n):
-                peakpts[i%(2*s)].point.set_ydata(self.fn(peak(i%(2*s)),**p0))
+            for i in range(n+1, 2*s+n):
+                peakpts[i%(2*s)].point.set_ydata(self.fn(peak(i%(2*s)), **p0))
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
         
         # make point for peak, updating nu_q 
-        def update_peak_edge(x,y,n):
+        def update_peak_edge(x, y, n):
             
             # amplitude
             p0['amp%d'%n] = self.base - y + \
-                        sum([lorentzian(peak(n),
-                                        peak(i%(2*s)),
-                                        p0['fwhm'],
-                                        p0['amp%d'%(i%(2*s))]) for i in range(n+1,2*s+n)])
+                        sum([lorentzian(peak(n), 
+                                        peak(i%(2*s)), 
+                                        p0['fwhm'], 
+                                        p0['amp%d'%(i%(2*s))]) for i in range(n+1, 2*s+n)])
             
             # get x and n of the other edge peak position
             other_n = 2*s-n-1
@@ -429,52 +428,52 @@ class FunctionPlacer(object):
             p0['nu_q'] = (x-p0['nu_0']) / ((np.sqrt(6) / 3) * (1 - 2 * (n-s+1)) * V_0)  
             
             # width point        
-            x2 = peak(0)+p0['fwhm']
+            x2 = peak(0)+p0['fwhm']/2
             widthpt.point.set_xdata(x2)
-            widthpt.point.set_ydata(self.fn(x2,**p0))
+            widthpt.point.set_ydata(self.fn(x2, **p0))
         
             # update the other peak points
-            for i in range(1,2*s-1):
+            for i in range(1, 2*s-1):
                 peakpts[i].point.set_xdata(peak(i))
-                peakpts[i].point.set_ydata(self.fn(peak(i),**p0))
-            peakpts[other_n].point.set_ydata(self.fn(other_x,**p0))
+                peakpts[i].point.set_ydata(self.fn(peak(i), **p0))
+            peakpts[other_n].point.set_ydata(self.fn(other_x, **p0))
             
             # update line
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sum line
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
         
         widthpt.updatefn = update_width
-        peakpts[0].updatefn = partial(update_peak_edge,n=0)
-        peakpts[2*s-1].updatefn = partial(update_peak_edge,n=2*s-1)
-        for i in range(1,2*s-1):
-            peakpts[i].updatefn = partial(update_peak_center,n=i)
+        peakpts[0].updatefn = partial(update_peak_edge, n=0)
+        peakpts[2*s-1].updatefn = partial(update_peak_edge, n=2*s-1)
+        for i in range(1, 2*s-1):
+            peakpts[i].updatefn = partial(update_peak_center, n=i)
         
-        return (*peakpts,widthpt)
+        return (*peakpts, widthpt)
         
     # ======================================================================= #
-    def run_20_initial(self,p0,line,color):
-        def update(x,y):
+    def run_20_initial(self, p0, line, color):
+        def update(x, y):
             # initial asymmetry
-            p0['amp'] = max(0,y)
-            line.set_ydata(self.fn(self.x,**p0))
+            p0['amp'] = max(0, y)
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sumline
             self.sumline.set_ydata(self.sumfn(self.x))
             self.fig.canvas.draw()    
              
         # return so matplotlib doesn't garbage collect
-        return DraggablePoint(self,update,0,p0['amp'],
-                              color=color,setx=False)
+        return DraggablePoint(self, update, 0, p0['amp'], 
+                              color=color, setx=False)
     
     # ======================================================================= #
-    def run_20_lambda(self,p0,line,color):
-        def update(x,y):
+    def run_20_lambda(self, p0, line, color):
+        def update(x, y):
             # 1/T1
             p0['lam'] = max(0, 1/x)
-            line.set_ydata(self.fn(self.x,**p0))
+            line.set_ydata(self.fn(self.x, **p0))
             
             # update sumline
             self.sumline.set_ydata(self.sumfn(self.x))
@@ -484,12 +483,12 @@ class FunctionPlacer(object):
         x = np.ones(1)/p0['lam']
         ylim = self.ax.get_ylim()[0]
         y = min([i for i in self.ax.get_yticks() if i>ylim])
-        return DraggablePoint(self, update, x, y,
+        return DraggablePoint(self, update, x, y, 
                               color=color, sety=False)
     
     # ======================================================================= #
-    def run_20_beta(self,p0,line,color):
-        def update(x,y):
+    def run_20_beta(self, p0, line, color):
+        def update(x, y):
     
             # beta - put y axis on a range of 0 to 1
             ylo, yhi = self.ax.get_ylim()
@@ -502,18 +501,18 @@ class FunctionPlacer(object):
             self.fig.canvas.draw()    
              
         # return so matplotlib doesn't garbage collect
-        ylo,yhi = self.ax.get_ylim()
-        xlo,xhi = self.ax.get_xlim()
+        ylo, yhi = self.ax.get_ylim()
+        xlo, xhi = self.ax.get_xlim()
         x = max([i for i in self.ax.get_xticks() if i < xhi])
-        return DraggablePoint(self, update, x, p0['beta']*(yhi-ylo)+ylo,
+        return DraggablePoint(self, update, x, p0['beta']*(yhi-ylo)+ylo, 
                               color=color, setx=False)
     
     # ======================================================================= #
-    def shift_20_pts_resize(self,event):
+    def shift_20_pts_resize(self, event):
         """Move the points so they fit in the screen"""
         
-        xlo,xhi = self.ax.get_xlim()
-        ylo,yhi = self.ax.get_ylim()
+        xlo, xhi = self.ax.get_xlim()
+        ylo, yhi = self.ax.get_ylim()
         
         for lam in self.list_points['lam']:
             ypos = lam.point.get_ydata()
@@ -525,14 +524,14 @@ class FunctionPlacer(object):
                 beta.point.set_xdata(max([i for i in self.ax.get_xticks() if i<xhi])) 
     
     # ======================================================================= #
-    def do_end(self,event):
+    def do_end(self, event):
         if event.key == 'enter':
             plt.close(self.fig.number)
-            self.endfn(self.p0,self.base)
+            self.endfn(self.p0, self.base)
         
 class dummybaseline(object):
     def __init__(self):pass
-    def set_ydata(self,y) : pass
+    def set_ydata(self, y) : pass
                 
 class DraggablePoint:
 
@@ -543,18 +542,18 @@ class DraggablePoint:
     size=0.01
 
     # ======================================================================= #
-    def __init__(self,parent,updatefn,x,y,setx=True,sety=True,color=None, marker='s'):
+    def __init__(self, parent, updatefn, x, y, setx=True, sety=True, color=None, marker='s'):
         """
             parent: parent object
             updatefn: funtion which updates the line in the correct way
-                updatefn(xdata,ydata)
-            x,y: initial point position
-            setx,sety: if true, allow setting this parameter
+                updatefn(xdata, ydata)
+            x, y: initial point position
+            setx, sety: if true, allow setting this parameter
             color: point color
         """
         self.parent = parent
-        self.point = parent.ax.plot(x,y,zorder=25,color=color,alpha=0.5,
-                                 marker=marker,markersize=8)[0]
+        self.point = parent.ax.plot(x, y, zorder=25, color=color, alpha=0.5, 
+                                 marker=marker, markersize=8)[0]
         
         self.point.set_pickradius(8)
         self.updatefn = updatefn
@@ -594,7 +593,7 @@ class DraggablePoint:
         if self.sety:   self.point.set_ydata(y)
 
         # update the line
-        self.updatefn(x,y)        
+        self.updatefn(x, y)        
 
     # ======================================================================= #
     def on_release(self, event):
