@@ -92,14 +92,34 @@ class fitdata(object):
     # ======================================================================= #
     def asym(self, *args, **kwargs):
         
-        # common deadtime
-        if '1' in self.mode:
-            return self.bd.asym(*args, deadtime=self.bfit.deadtime_1f, **kwargs)
+        deadtime = 0
+        
+        # check if deadtime corrections are needed
+        if self.bfit.deadtime_switch.get():
             
-        # individual deadtimes
-        else:            
-            return self.bd.asym(*args, deadtime=self.deadtime, **kwargs)
+            # check if corrections should be calculated for each run
+            if self.bfit.deadtime_global.get():
+                deadtime = self.bfit.deadtime
+            else:
+                deadtime = self.bd.get_deadtime(c=self.bfit.deadtime, fixed='c')
+                
+        return self.bd.asym(*args, deadtime=deadtime, **kwargs)
 
+    # ======================================================================= #
+    @property
+    def beam_kev(self): 
+        try:
+            return self.bd.beam_kev()
+        except AttributeError:
+            return np.nan
+    
+    @property
+    def beam_kev_err(self): 
+        try:
+            return self.bd.beam_kev(get_error=True)
+        except AttributeError:
+            return np.nan
+        
     # ======================================================================= #
     def get_temperature(self, channel='A'):
         """
@@ -179,12 +199,6 @@ class fitdata(object):
             self.logger.exception('Bias not found')
             self.bias = np.nan
             
-        # deadtime
-        if self.mode in ('20', '2h'):
-            self.deadtime = self.bd.get_deadtime()
-        else:
-            self.deadtime = 0
-
     # ======================================================================= #
     def set_fitpar(self, values):
         """Set fitting initial parameters
@@ -222,7 +236,6 @@ class fitdata(object):
         
         self.logger.debug('Setting fit results to %s', self.fitpar)
     
-
 # ========================================================================== #
 class temperature_class(object):
     """
